*$ CREATE MAGFLD.FOR
*COPY MAGFLD
*
*===magfld=============================================================*
*
      SUBROUTINE MAGFLD ( X, Y, Z, BTX, BTY, BTZ, B, NREG, IDISC )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1988-2005      by Alberto Fasso` & Alfredo Ferrari *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     Created  in 1988    by     Alberto Fasso`, CERN - TIS            *
*                                                                      *
*     Last change on 11-dec-92     by    Alfredo Ferrari               *
*                                                                      *
*     Input variables:                                                 *
*            x,y,z = current position                                  *
*            nreg  = current region                                    *
*     Output variables:                                                *
*            btx,bty,btz = cosines of the magn. field vector           *
*            B = magnetic field intensity (Tesla)                      *
*            idisc = set to 1 if the particle has to be discarded      *
*                                                                      *
*----------------------------------------------------------------------*
*
      IDISC = 0
c   quadrupole field (k=100 T/m)
      GRADIENT=ONEONE
      RADPOS=SQRT(X**2+Y**2)
      IF(RADPOS.GT.ZERZER) THEN
        B=GRADIENT*RADPOS
        BTX=Y/RADPOS
        BTY=X/RADPOS
      ELSE
        B=ZERZER
        BTX=ONEONE
        BTY=ZERZER
      ENDIF
      BTZ=ZERZER
      RETURN
*=== End of subroutine magfld =========================================*
      END
